@@ -1,7 +1,7 @@
-export TARGET=$HOME/net/home/opt/mac
-export SRCDIR=$HOME/net/home/prog/mac/source
-export PACKAGE_DIR=$HOME/prog/mac/packages
-export DOCBOOK_XSL_ROOT_DIR=$HOME/prog/mac/xsl-stylesheets
+export TARGET=$HOME/opt
+export SRCDIR=$HOME/opt/source
+export PACKAGE_DIR=$HOME/opt/packages
+export DOCBOOK_XSL_ROOT_DIR=$HOME/opt/xsl-stylesheets
 export CMPL=$HOME/tmp/compile
 export PATH=${TARGET}/bin:$PATH
 export CC="clang"
@@ -11,7 +11,7 @@ export CXXCPP="clang++ -E"
 export CFLAGS=""
 export CXXFLAGS="-std=c++17"
 export QT_CXXFLAGS="-stdlib=libc++"
-export MACOSX_DEPLOYMENT_TARGET="10.14"
+export MACOSX_DEPLOYMENT_TARGET="10.15"
 export DRAKETHREADS=${DRAKETHREADS:-4}
 export MAKEFLAGS="-j ${DRAKETHREADS}"
 export SHARED_QT=1
